@@ -46,13 +46,13 @@ BIBTYPE_NAMES = {
 }
 
 
-def to_html(entry, *, config: Config, single_indent: int = 2) -> str:
+def to_html(entry, *, config: Config) -> str:
     elements = [
         indent(0, f'<li class="bibentry" id="{html_id(entry)}">'),
         indent(1, '<span class="main-info">'),
         indent(2, authors_to_html(entry, config)),
-        indent(2, publication_title_to_html(entry, config)),
-        indent(2, talk_type_to_html(entry, config)),
+        indent(2, publication_title_to_html(entry)),
+        indent(2, talk_type_to_html(entry)),
         indent(2, publication_venue_to_html(entry, config)),
         indent(2, publisher_to_html(entry)),
         indent(2, doi_to_html(entry)),
@@ -64,8 +64,8 @@ def to_html(entry, *, config: Config, single_indent: int = 2) -> str:
         indent(1, '<span class="additional-info">'),
         indent(2, '<span class="inline-info">'),
         indent(3, note_to_html(entry)),
-        indent(3, keywords_to_html(entry)),
-        indent(3, funders_to_html(entry)),
+        indent(3, keywords_to_html(entry, config)),
+        indent(3, funders_to_html(entry, config)),
         indent(2, "</span>"),
         indent(2, '<span class="link-list">'),
         indent(3, publisher_version_to_html(entry)),
@@ -87,6 +87,19 @@ def to_html(entry, *, config: Config, single_indent: int = 2) -> str:
     return "\n".join(elements)
 
 
+def internal_link(
+    text: str, href: str, config: Config, title: str = "", css_class: str = ""
+) -> str:
+    if not config.create_internal_links:
+        return text
+    else:
+        if title:
+            title = f' title="{title}"'
+        if css_class:
+            css_class = f' class="{css_class}"'
+        return f'<a{css_class} href="{href}"{title}>{text}</a>'
+
+
 def indent(n: int, content, single_indent: int = 2):
     lines = content.split("\n")
     spaces = n * single_indent * " "
@@ -94,14 +107,14 @@ def indent(n: int, content, single_indent: int = 2):
     return "\n".join(indented_lines)
 
 
-def publication_title_to_html(entry, config):
+def publication_title_to_html(entry):
     title = entry.get("title")
     if not title:
         return ""
     return f'<span class="publication-title">{title}.</span>'
 
 
-def talk_type_to_html(entry, config):
+def talk_type_to_html(entry):
     html = ""
     entrytype = entry["ENTRYTYPE"]
     if entrytype == "conferencetalk":
@@ -183,7 +196,7 @@ def editors_to_html(entry, config: Config):
     return f'<span class="editor-list">{editors_html}</span>'
 
 
-def funders_to_html(entry):
+def funders_to_html(entry, config):
     try:
         funders = entry["funding"]
     except KeyError:
@@ -191,7 +204,9 @@ def funders_to_html(entry):
     html_items = list()
     for f in funders:
         html_items.append(
-            f'<a class="funding" href="../Funding/{_keyword_to_link(f)}">{f}</a>'
+            internal_link(
+                f, f"../Funding/{_keyword_to_link(f)}", config, css_class="funding"
+            )
         )
     funders_html = ",\n".join(html_items)
     return f'<span class="funding-list">Funding:\n{indent(1, funders_html)}\n</span>'
@@ -214,7 +229,7 @@ def _get_list_of_names(
     for a in names:
         html_a = _name_to_html(a)
         if config.index_author(a):
-            html_a = f'<a href="../Author/{_author_to_link(a)}">{html_a}</a>'
+            html_a = internal_link(html_a, f"../Author/{_author_to_link(a)}", config)
         ls.append(f'<span class="{css_class}">{html_a}</span>')
     if len(ls) > 2:
         ls = [delimiter_intermediate.join(ls[:-1]), ls[-1]]
@@ -359,12 +374,17 @@ def artifacts_to_html(entry):
     return _create_details("Artifact(s)", artifacts_html, "artifact-list")
 
 
-def keywords_to_html(entry):
+def keywords_to_html(entry, config):
     keywords = get_keywords(entry)
     if not keywords:
         return ""
     keyword_htmls = [
-        f'<a class="keyword" href="../Keyword/{_keyword_to_link(keyword)}">{keyword}</a>'
+        internal_link(
+            keyword,
+            f"../Keyword/{_keyword_to_link(keyword)}",
+            config,
+            css_class="keyword",
+        )
         for keyword in keywords
     ]
     keyword_html = ",\n".join(keyword_htmls)
@@ -474,7 +494,9 @@ def writes(
             yield head
         for category, entries in categorized_entries.items():
             if category.link:
-                yield f'<a href="../{category.link}"><h3>{category.name}</h3></a>'
+                yield internal_link(
+                    f"<h3>{category.name}</h3>", f"../{category.link}", config
+                )
             else:
                 yield f"<h3>{category.name}</h3>"
             yield ""
@@ -515,12 +537,20 @@ def write_html(output_obj, html: str):
     output_obj.write(end)
 
 
-def _get_header(header, show_link_to_index=True, show_link_to_all=True):
+def _get_header(header, config, show_link_to_index=True, show_link_to_all=True):
     def maybe_all():
-        return ['<a href="../All/index.html">Show all</a>'] if show_link_to_all else []
+        return (
+            ['<a href="../All/index.html">Show all</a>']
+            if config.create_internal_links and show_link_to_all
+            else []
+        )
 
     def maybe_index():
-        return ['<a href="../index.html">Index</a>'] if show_link_to_index else []
+        return (
+            ['<a href="../index.html">Index</a>']
+            if config.create_internal_links and show_link_to_index
+            else []
+        )
 
     def links():
         links = maybe_all() + maybe_index()
@@ -543,7 +573,7 @@ def write_html_tree(entries: Sequence[dict], output_root, *, config, header_titl
     write_by_year(
         entries,
         output_file=output_root / "All" / "index.html",
-        head=_get_header(header=header_title, show_link_to_all=False),
+        head=_get_header(header=header_title, config=config, show_link_to_all=False),
         header_title=header_title,
         config=config,
     )
@@ -584,7 +614,10 @@ def write_html_tree(entries: Sequence[dict], output_root, *, config, header_titl
 
     def index_page(header_title):
         yield _get_header(
-            f"Index of {header_title}", show_link_to_all=False, show_link_to_index=False
+            f"Index of {header_title}",
+            config,
+            show_link_to_all=False,
+            show_link_to_index=False,
         )
         if created_pages["year"]:
             yield '<h3 id="years">Selection by year</h3>'
@@ -648,7 +681,7 @@ def write_year_tree(entries: Sequence[dict], output_root, *, config, header_titl
             write_by_type(
                 es,
                 output_file,
-                head=_get_header(f"{header_title} of year {year.name}"),
+                head=_get_header(f"{header_title} of year {year.name}", config),
                 config=config,
                 header_title=header_title,
             )
@@ -695,7 +728,7 @@ def write_author_tree(
             write_by_type(
                 es,
                 output_file,
-                head=_get_header(f"{header_title} of {author.name}"),
+                head=_get_header(f"{header_title} of {author.name}", config),
                 config=config,
                 header_title=header_title,
             )
@@ -718,7 +751,7 @@ def write_keyword_tree(
             write_by_type(
                 es,
                 output_file,
-                head=_get_header(f"{header_title} about {keyword.name}"),
+                head=_get_header(f"{header_title} about {keyword.name}", config),
                 config=config,
                 header_title=header_title,
             )
@@ -741,7 +774,7 @@ def write_funding_tree(
             write_by_type(
                 es,
                 output_file,
-                head=_get_header(f"Funding by {funding.name}"),
+                head=_get_header(f"Funding by {funding.name}", config),
                 config=config,
                 header_title=header_title,
             )
@@ -753,9 +786,9 @@ def write_funding_tree(
 def _get_named_types(entries):
     by_type = categories.by_type(entries)
     named_types = defaultdict(list)
-    for bibtype, entries in by_type.items():
+    for bibtype, es in by_type.items():
         name = BIBTYPE_NAMES[bibtype]
-        named_types[name] += entries
+        named_types[name] += es
     return {k: categories.sort_by_year(v) for k, v in named_types.items()}
 
 
