@@ -59,7 +59,7 @@ def get_shortform(author_name: str) -> str:
         return f"{name[0]}."
 
     def handle_dashes(first_name, handle_single_name):
-        return "-".join([handle_single_name(p) for p in name.split("-")])
+        return "-".join([handle_single_name(p) for p in first_name.split("-")])
 
     first_names, last_name = split_name(author_name)
     first_names = get_all_name_parts(first_names)
